@@ -25,7 +25,7 @@ from onnx2tf.utils.common_functions import (
     onnx_tf_tensor_validation,
 )
 from typing import Any, Dict
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 
 INF_INDEX_VALUE: int = 4294967296
 
@@ -227,8 +227,18 @@ def make_node(
     # Check auto_pad nonexistent or NOTSET first
     pad_mode = 'VALID'
     padded = False
+
+    # for onnx pads that diff on the side of axes
+    # for example [3,1] or [3,3,3,1]
+    pads_axes_opposite_same = True
+    for axis_begin, axis_end in zip(pads[0:spatial_size:1], pads[spatial_size::1]):
+        if axis_begin != axis_end:
+            pads_axes_opposite_same = False
+            break
+
     if auto_pad == 'NOTSET':
-        if input_tensor_rank >=2 \
+        if pads_axes_opposite_same \
+            and input_tensor_rank >=2 \
             and graph_node.inputs[0].shape is not None \
             and graph_node.inputs[0].shape[2:] == output_tensor_shape[2:]:
             pad_mode = "SAME"
@@ -248,13 +258,13 @@ def make_node(
         pad_mode = "VALID"
     elif auto_pad == "SAME_LOWER":
         error_msg = f'' +\
-            f'{Color.RED}ERROR:{Color.RESET} ' +\
+            Color.RED(f'ERROR:') + ' ' +\
             f'Invalid auto_pad attribute: {auto_pad}'
         print(error_msg)
         assert False, error_msg
     else:
         error_msg = f'' +\
-            f'{Color.RED}ERROR:{Color.RESET} ' +\
+            Color.RED(f'ERROR:') + ' ' +\
             f'Invalid auto_pad attribute: {auto_pad}'
         print(error_msg)
         assert False, error_msg
@@ -453,8 +463,7 @@ def make_node(
 
             else:
                 if kernel_size in (1, 2, 3) and not disable_group_convolution:
-                    print(
-                        f'{Color.YELLOW}WARNING:{Color.RESET} ' +\
+                    warn(
                         f'This model contains GroupConvolution and is automatically optimized for TFLite, ' +
                         f'but is not output because saved_model does not support GroupConvolution. ' +
                         f'If saved_model is needed, specify --disable_group_convolution to retransform the model.'
@@ -513,8 +522,6 @@ def make_node(
 
                 else:
                     # SeparableConv
-                    input_tensor_splits = tf.split(input_tensor, num_or_size_splits=group, axis=-1)
-                    weight_splits = tf.split(input_weights, num_or_size_splits=group, axis=-1)
                     tf_layers_dict[graph_node_output.name]['tf_node'] = \
                         sep_conv_bias(
                             input_tensor,
@@ -559,8 +566,7 @@ def make_node(
 
             else:
                 if kernel_size in (1, 2, 3) and not disable_group_convolution:
-                    print(
-                        f'{Color.YELLOW}WARNING:{Color.RESET} ' +\
+                    warn(
                         f'This model contains GroupConvolution and is automatically optimized for TFLite, ' +
                         f'but is not output because saved_model does not support GroupConvolution. ' +
                         f'If saved_model is needed, specify --disable_group_convolution to retransform the model.'
@@ -614,8 +620,6 @@ def make_node(
 
                 else:
                     # SeparableConv
-                    input_tensor_splits = tf.split(input_tensor, num_or_size_splits=group, axis=-1)
-                    weight_splits = tf.split(input_weights, num_or_size_splits=group, axis=-1)
                     tf_layers_dict[graph_node_output.name]['tf_node'] = \
                         sep_conv_nobias(
                             input_tensor,
