@@ -17,13 +17,11 @@ from onnx2tf.utils.common_functions import (
     post_process_transpose,
     disable_unnecessary_transpose,
     shape_unmatched_special_avoidance_workaround,
-    make_tf_partial_model_inputs,
-    dummy_tf_inference,
     merge_two_consecutive_identical_ops_into_one,
     deterring_shape_corruption_due_to_broadcast,
+    correction_process_for_accuracy_errors,
+    nhwc_determination_of_output_value_of_binary_input_op,
 )
-from typing import Any, Dict, List
-from onnx2tf.utils.enums import TF_DTYPES_TO_NUMPY_DTYPES
 
 
 @print_node_info
@@ -70,6 +68,12 @@ def make_node(
         'optype': graph_node.op,
         'shape': graph_node_output_shape,
         'dtype': dtype,
+        'nhwc': \
+            nhwc_determination_of_output_value_of_binary_input_op(
+                graph_node_input_1=graph_node_input_1,
+                graph_node_input_2=graph_node_input_2,
+                tf_layers_dict=tf_layers_dict
+            )
     }
 
     input_tensor_1 = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
@@ -77,6 +81,10 @@ def make_node(
     input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    disable_strict_mode: bool = kwargs['disable_strict_mode']
+    replace_erf_to_pseudo_gelu = "gelu" in kwargs['replace_to_pseudo_operators']
+    mul_div_replace_op_names: dict = kwargs['mul_div_replace_op_names']
+
     # Param replacement
     input_tensor_1 = replace_parameter(
         value_before_replacement=input_tensor_1,
@@ -105,24 +113,11 @@ def make_node(
         **kwargs,
     )
 
-    # Acquisition of test data for validation
-    if kwargs['acc_check']:
-        if not isinstance(graph_node_input_1, np.ndarray) \
-            and graph_node_input_1.name in tf_layers_dict \
-            and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
-            test_data1: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
-        elif isinstance(graph_node_input_1, np.ndarray):
-            test_data1: np.ndarray = graph_node_input_1
-        else:
-            test_data1 = None
-        if not isinstance(graph_node_input_2, np.ndarray) \
-            and graph_node_input_2.name in tf_layers_dict \
-            and 'verification_data' in tf_layers_dict[graph_node_input_2.name].keys():
-            test_data2: np.ndarray = tf_layers_dict[graph_node_input_2.name]['verification_data']
-        elif isinstance(graph_node_input_2, np.ndarray):
-            test_data2: np.ndarray = graph_node_input_2
-        else:
-            test_data2 = None
+    # Workaround for ConvInteger
+    if input_tensor_1.dtype == tf.float32 and input_tensor_2.dtype in [tf.int32, tf.int64]:
+        input_tensor_2 = tf.cast(input_tensor_2, dtype=tf.float32)
+    elif input_tensor_1.dtype in [tf.int32, tf.int64] and input_tensor_2.dtype == tf.float32:
+        input_tensor_1 = tf.cast(input_tensor_1, dtype=tf.float32)
 
     # Disable unnecessary Transpose
     #   1. If both x and y are gs.Variable
@@ -142,26 +137,29 @@ def make_node(
     # At least one True value for same_input_shape_as_onnx
     # At least one True value in nhwc_flags
     # same_input_shape_as_onnx == True and nhwc_flags == False and 3D or 4D or 5D tensor is NHWC transposed
-    input_tensor_1, input_tensor_2 = shape_unmatched_special_avoidance_workaround(
-        graph_node_input_1=graph_node_input_1,
-        graph_node_input_2=graph_node_input_2,
-        input_tensor_1=input_tensor_1,
-        input_tensor_2=input_tensor_2,
-        tf_layers_dict=tf_layers_dict,
-        **kwargs,
-    )
+    input_tensor_1, input_tensor_2 = \
+        shape_unmatched_special_avoidance_workaround(
+            graph_node_input_1=graph_node_input_1,
+            graph_node_input_2=graph_node_input_2,
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+            tf_layers_dict=tf_layers_dict,
+            **kwargs,
+        )
 
-    input_tensor_1, input_tensor_2 = pre_explicit_broadcast(
-        input_tensor_1=input_tensor_1,
-        input_tensor_2=input_tensor_2,
-    )
+    input_tensor_1, input_tensor_2 = \
+        pre_explicit_broadcast(
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+        )
 
-    input_tensor_1, input_tensor_2 = explicit_broadcast(
-        const_or_var_1=input_tensor_1,
-        const_or_var_2=input_tensor_2,
-        graph_node=graph_node,
-        tf_layers_dict= tf_layers_dict,
-    )
+    input_tensor_1, input_tensor_2 = \
+        explicit_broadcast(
+            const_or_var_1=input_tensor_1,
+            const_or_var_2=input_tensor_2,
+            graph_node=graph_node,
+            tf_layers_dict= tf_layers_dict,
+        )
 
     # Deterring shape corruption due to broadcast
     input_tensor_1, input_tensor_2 = \
@@ -171,6 +169,20 @@ def make_node(
             input_tensor_2=input_tensor_2,
         )
 
+    # Correction process for accuracy errors
+    if not disable_strict_mode:
+        input_tensor_1, input_tensor_2 = \
+            correction_process_for_accuracy_errors(
+                input_tensor_1=input_tensor_1,
+                input_tensor_2=input_tensor_2,
+                tf_func=tf.math.divide,
+                np_func=np.divide,
+                graph_node_output_shape=graph_node_output_shape,
+                graph_node_output=graph_node_output,
+                tf_layers_dict=tf_layers_dict,
+                **kwargs,
+            )
+
     # Generation of TF OP
     target_cast_dtype = [
         np.int8,
@@ -188,20 +200,7 @@ def make_node(
     input_tensor_2 = input_tensor_2 \
         if not xy_is_integer else tf.cast(input_tensor_2, dtype=tf.float32)
 
-    # Generate input OPs for TensorFlow subgraphs
-    # For inference testing on OP stand-alone
-    if kwargs['acc_check']:
-        tf_partial_model_inputs: List[tf.keras.Input] = \
-            make_tf_partial_model_inputs(
-                input_tensors=[
-                    input_tensor_1,
-                    input_tensor_2,
-                ]
-            )
-        tf_partial_model_outputs = None
-
     # Generation of TF OP
-    ### Overall model
     # TODO: Temporarily Revert due to missing decision conditions
     # # Merge two consecutive identical OPs into one
     # # https://github.com/PINTO0309/onnx2tf/issues/230
@@ -230,55 +229,100 @@ def make_node(
     #     tf_layers_dict=tf_layers_dict,
     #     tf_func='Div'
     # )
-    divided_tensor = tf.math.divide(
-        x=input_tensor_1,
-        y=input_tensor_2,
-        name=graph_node.name,
-    )
-    tf_type = tf.math.divide
 
-    ### Partial model
-    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
-        tf_partial_model_outputs = \
-            [
-                tf.math.divide(
-                    x=tf_partial_model_inputs[0] \
-                        if not isinstance(tf_partial_model_inputs[0], np.ndarray) \
-                            else tf.convert_to_tensor(tf_partial_model_inputs[0]),
-                    y=tf_partial_model_inputs[1] \
-                        if not isinstance(tf_partial_model_inputs[1], np.ndarray) \
-                            else tf.convert_to_tensor(tf_partial_model_inputs[1]),
-                )
-            ]
-        tf_partial_model = tf.keras.Model(
-            inputs=tf_partial_model_inputs,
-            outputs=tf_partial_model_outputs,
+    # GeLU replace check
+    # https://github.com/PINTO0309/onnx2tf/issues/465
+    # a. x -> b.Div (a*1.4142135381698608) -> c.Erf (b) -> d.Add (c+1.0) -> e.Mul (a*d) -> f.Mul (f*0.5)
+    enable_gelu = False
+    if hasattr(input_tensor_2, 'numpy') and input_tensor_2.numpy() == 1.4142135:
+        try:
+            input_node_name = graph_node_input_1.name
+            erf_node: gs.Node = None
+            add_node: gs.Node = None
+            mul_1_node: gs.Node = None
+            mul_2_node: gs.Node = None
+            if graph_node.o().op == 'Erf':
+
+                erf_node = graph_node.o()
+
+                if erf_node.o().op == 'Add' \
+                    and len(erf_node.o().inputs) == 2 \
+                    and isinstance(graph_node.o().o().inputs[1], gs.Constant) \
+                    and hasattr(erf_node.o().inputs[1], 'values') \
+                    and erf_node.o().inputs[1].values == 1.0:
+
+                    add_node = erf_node.o()
+
+                    if add_node.o().op == 'Mul' \
+                        and len(add_node.o().inputs) == 2 \
+                        and add_node.o().inputs[0].name == input_node_name:
+
+                        mul_1_node = add_node.o()
+
+                        if mul_1_node.o().op == 'Mul' \
+                            and isinstance(mul_1_node.o().inputs[1], gs.Constant) \
+                            and hasattr(mul_1_node.o().inputs[1], 'values') \
+                            and mul_1_node.o().inputs[1].values == 0.5:
+
+                            mul_2_node = mul_1_node.o()
+
+                            # Save the name of the OP set to be replaced to GeLU
+                            # Div, Erf, Add, Mul, Mul
+                            if 'gelu_replace_op_names' not in kwargs:
+                                kwargs['gelu_replace_op_names'] = {}
+                            kwargs['gelu_replace_op_names'][graph_node.name] = [
+                                erf_node.name,
+                                add_node.name,
+                                mul_1_node.name,
+                                mul_2_node.name,
+                            ]
+                            enable_gelu = True
+        except:
+            pass
+
+    # Replace with GeLU if available.
+    mul_div_op_names = [op_name for op_names in mul_div_replace_op_names.values() for op_name in op_names]
+    disable_div = graph_node.name in mul_div_op_names
+
+    # Replace with GeLU if available.
+    if not enable_gelu:
+        if not disable_div:
+            divided_tensor = tf.math.divide(
+                x=input_tensor_1,
+                y=input_tensor_2,
+                name=graph_node.name,
+            )
+            tf_type = tf.math.divide
+        else:
+            if len(graph_node.inputs) == 2 \
+                and graph_node.inputs[0].name in tf_layers_dict \
+                and tf_layers_dict[graph_node.inputs[0].name]['optype'] == 'Input':
+                divided_tensor = \
+                    tf.identity(
+                        input=tf_layers_dict[graph_node.inputs[1].name]['tf_node'],
+                        name=graph_node.name,
+                    )
+            elif len(graph_node.inputs) == 2 \
+                and graph_node.inputs[1].name in tf_layers_dict \
+                and tf_layers_dict[graph_node.inputs[1].name]['optype'] == 'Input':
+                divided_tensor = \
+                    tf.identity(
+                        input=tf_layers_dict[graph_node.inputs[0].name]['tf_node'],
+                        name=graph_node.name,
+                    )
+            else:
+                divided_tensor = \
+                    tf.identity(
+                        input=input_tensor_1 if graph_node.i(0).name in mul_div_replace_op_names else input_tensor_2,
+                        name=graph_node.name,
+                    )
+            tf_type = tf.identity
+    else:
+        divided_tensor = tf.nn.gelu(
+            features=input_tensor_1,
+            approximate=replace_erf_to_pseudo_gelu,
         )
-        test_data1 = None
-        if isinstance(input_tensor_1, np.ndarray):
-            test_data1 = input_tensor_1
-        test_data2 = None
-        if isinstance(input_tensor_2, np.ndarray):
-            test_data2 = input_tensor_2
-        tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
-            model=tf_partial_model,
-            inputs=tf_partial_model_inputs,
-            verification_datas=[
-                test_data1,
-                test_data2,
-            ]
-        )
-        tf_partial_model_result: np.ndarray = list(tf_partial_model_result_infos.values())[0]
-        if xy_is_integer and dtype in target_cast_dtype:
-            cast_dtype = TF_DTYPES_TO_NUMPY_DTYPES[dtype] \
-                if isinstance(dtype, tf.dtypes.DType) else dtype
-            tf_partial_model_result = tf_partial_model_result.astype(cast_dtype)
-        tf_layers_dict[graph_node_output.name]['verification_data'] = tf_partial_model_result
-        del tf_partial_model
-        del tf_partial_model_inputs
-        del tf_partial_model_outputs
-        del test_data1
-        del test_data2
+        tf_type = tf.identity
 
     # Post-process transpose
     divided_tensor = post_process_transpose(
