@@ -53,6 +53,8 @@ def make_node(
     graph_node_input_2 = get_constant_or_variable(
         graph_node.inputs[1],
         before_op_output_shape_trans,
+        is_bias=True \
+            if graph_node.inputs[1].shape is None or len(graph_node.inputs[1].shape) == 1 else False
     )
     graph_node_output: gs.Variable = graph_node.outputs[0]
 
@@ -138,6 +140,9 @@ def make_node(
         'optype': graph_node.op,
         'shape': shape,
         'dtype': dtype,
+        'nhwc': tf_layers_dict[graph_node_input_1.name]['nhwc'] \
+            if isinstance(graph_node_input_1, gs.Variable) \
+                and 'nhwc' in tf_layers_dict[graph_node_input_1.name].keys() else False
     }
 
     # Param replacement
