@@ -17,7 +17,7 @@ from onnx2tf.utils.common_functions import (
     calc_extra_padding_with_ceil,
     transpose_with_flexing_deterrence,
 )
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
 
 INF_INDEX_VALUE: int = 4294967296
@@ -65,7 +65,7 @@ def make_node(
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
     input_tensor_shape = input_tensor.shape
 
-    non_verbose = bool(kwargs['non_verbose'])
+    output_integer_quantized_tflite = bool(kwargs['output_integer_quantized_tflite'])
 
     # Pre-process transpose
     input_tensor = pre_process_transpose(
@@ -130,7 +130,7 @@ def make_node(
 
     if len(graph_node.outputs) > 1 and dilations != [1] * spatial_size:
         error_msg = \
-            f'{Color.RED}ERROR:{Color.RESET} ' \
+            Color.RED(f'ERROR:') + ' ' \
             f'MaxPoolWithArgmax with dilations is not yet implemented. ' \
             f'Pull requests are welcome. \n' \
             f'graph_node.name: {graph_node.name}, dilations: {dilations}'
@@ -144,7 +144,7 @@ def make_node(
     input_tensor_dtype = input_tensor.dtype
 
     if storage_order:
-        error_msg = f'{Color.RED}ERROR:{Color.RESET} ' + \
+        error_msg = Color.RED(f'ERROR:') + ' ' + \
                     f'storage_order option is not implemented yet.'
         print(error_msg)
         raise NotImplementedError(error_msg)
@@ -201,18 +201,16 @@ def make_node(
         tf_pads = [0] * spatial_size * 2
 
     else:
-        error_msg = f'{Color.RED}ERROR:{Color.RESET} ' + \
+        error_msg = Color.RED(f'ERROR:') + ' ' + \
                     f'Wrong auto_pad parameter in MaxPool: {auto_pad}.'
         raise ValueError(error_msg)
 
     # add extra pad layer if needed
     if is_explicit_padding and tf_pads != [0] * spatial_size * 2:
-        if not non_verbose:
-            warning_msg = \
-                f'{Color.YELLOW}WARNING:{Color.RESET} ' \
-                f'Tensorflow incompatible padding detected. ' \
-                f'Extra pad layer is inserted automatically. '
-            print(warning_msg)
+        warn(
+            f'Tensorflow incompatible padding detected. ' \
+            f'Extra pad layer is inserted automatically. '
+        )
 
         if auto_pad == 'SAME_LOWER':
             # switch the order of pads
@@ -225,11 +223,15 @@ def make_node(
             [[0, 0]]
 
         # use minimum limit value of data type for explicit padding value since this is max pooling
+        # https://github.com/PINTO0309/onnx2tf/issues/444
+        # Implemented a workaround to deal with the problem that padding with the minimum value causes
+        # the output error of `MaxPool2D` to be maximized only when quantizing with INT8 quantization.
         padded_tensor = tf.pad(
             tensor=input_tensor,
             paddings=tf_pads,
             mode='CONSTANT',
-            constant_values=input_tensor.dtype.min
+            constant_values=input_tensor.dtype.min \
+                if not output_integer_quantized_tflite else 0.0
         )
 
     else:
@@ -305,7 +307,7 @@ def make_node(
         else:
             # TODO: Dilated MaxPool with strides is broken for 3D and above, need to be fixed
             if spatial_size >= 3:
-                error_msg = f'{Color.RED}ERROR:{Color.RESET} ' \
+                error_msg = Color.RED(f'ERROR:') + ' ' \
                             f'Dilated MaxPool with strides is not supported for 3D and above for now. '
                 print(error_msg)
                 raise NotImplementedError(error_msg)
