@@ -17,11 +17,10 @@ from onnx2tf.utils.common_functions import (
     get_replacement_parameter,
     pre_process_transpose,
     post_process_transpose,
-    make_tf_partial_model_inputs,
-    dummy_tf_inference,
     deterring_shape_corruption_due_to_broadcast,
+    correction_process_for_accuracy_errors,
+    nhwc_determination_of_output_value_of_binary_input_op,
 )
-from typing import Any, Dict, List
 
 
 @print_node_info
@@ -68,6 +67,12 @@ def make_node(
         'optype': graph_node.op,
         'shape': graph_node_output_shape,
         'dtype': dtype,
+        'nhwc': \
+            nhwc_determination_of_output_value_of_binary_input_op(
+                graph_node_input_1=graph_node_input_1,
+                graph_node_input_2=graph_node_input_2,
+                tf_layers_dict=tf_layers_dict
+            )
     }
 
     # Generation of TF OP
@@ -76,6 +81,8 @@ def make_node(
     input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    disable_strict_mode: bool = kwargs['disable_strict_mode']
+
     # Param replacement
     input_tensor_1 = replace_parameter(
         value_before_replacement=input_tensor_1,
@@ -104,24 +111,11 @@ def make_node(
         **kwargs,
     )
 
-    # Acquisition of test data for validation
-    if kwargs['acc_check']:
-        if not isinstance(graph_node_input_1, np.ndarray) \
-            and graph_node_input_1.name in tf_layers_dict \
-            and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
-            test_data1: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
-        elif isinstance(graph_node_input_1, np.ndarray):
-            test_data1: np.ndarray = graph_node_input_1
-        else:
-            test_data1 = None
-        if not isinstance(graph_node_input_2, np.ndarray) \
-            and graph_node_input_2.name in tf_layers_dict \
-            and 'verification_data' in tf_layers_dict[graph_node_input_2.name].keys():
-            test_data2: np.ndarray = tf_layers_dict[graph_node_input_2.name]['verification_data']
-        elif isinstance(graph_node_input_2, np.ndarray):
-            test_data2: np.ndarray = graph_node_input_2
-        else:
-            test_data2 = None
+    # Workaround for ConvInteger
+    if input_tensor_1.dtype == tf.float32 and input_tensor_2.dtype in [tf.int32, tf.int64]:
+        input_tensor_2 = tf.cast(input_tensor_2, dtype=tf.float32)
+    elif input_tensor_1.dtype in [tf.int32, tf.int64] and input_tensor_2.dtype == tf.float32:
+        input_tensor_1 = tf.cast(input_tensor_1, dtype=tf.float32)
 
     # Disable unnecessary Transpose
     #   1. If both x and y are gs.Variable
@@ -141,26 +135,29 @@ def make_node(
     # At least one True value for same_input_shape_as_onnx
     # At least one True value in nhwc_flags
     # same_input_shape_as_onnx == True and nhwc_flags == False and 3D or 4D or 5D tensor is NHWC transposed
-    input_tensor_1, input_tensor_2 = shape_unmatched_special_avoidance_workaround(
-        graph_node_input_1=graph_node_input_1,
-        graph_node_input_2=graph_node_input_2,
-        input_tensor_1=input_tensor_1,
-        input_tensor_2=input_tensor_2,
-        tf_layers_dict=tf_layers_dict,
-        **kwargs,
-    )
+    input_tensor_1, input_tensor_2 = \
+        shape_unmatched_special_avoidance_workaround(
+            graph_node_input_1=graph_node_input_1,
+            graph_node_input_2=graph_node_input_2,
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+            tf_layers_dict=tf_layers_dict,
+            **kwargs,
+        )
 
-    input_tensor_1, input_tensor_2 = pre_explicit_broadcast(
-        input_tensor_1=input_tensor_1,
-        input_tensor_2=input_tensor_2,
-    )
+    input_tensor_1, input_tensor_2 = \
+        pre_explicit_broadcast(
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+        )
 
-    input_tensor_1, input_tensor_2 = explicit_broadcast(
-        const_or_var_1=input_tensor_1,
-        const_or_var_2=input_tensor_2,
-        graph_node=graph_node,
-        tf_layers_dict= tf_layers_dict,
-    )
+    input_tensor_1, input_tensor_2 = \
+        explicit_broadcast(
+            const_or_var_1=input_tensor_1,
+            const_or_var_2=input_tensor_2,
+            graph_node=graph_node,
+            tf_layers_dict= tf_layers_dict,
+        )
 
     # Deterring shape corruption due to broadcast
     input_tensor_1, input_tensor_2 = \
@@ -170,20 +167,21 @@ def make_node(
             input_tensor_2=input_tensor_2,
         )
 
-    # Generate input OPs for TensorFlow subgraphs
-    # For inference testing on OP stand-alone
-    if kwargs['acc_check']:
-        tf_partial_model_inputs: List[tf.keras.Input] = \
-            make_tf_partial_model_inputs(
-                input_tensors=[
-                    input_tensor_1,
-                    input_tensor_2,
-                ]
+    # Correction process for accuracy errors
+    if not disable_strict_mode:
+        input_tensor_1, input_tensor_2 = \
+            correction_process_for_accuracy_errors(
+                input_tensor_1=input_tensor_1,
+                input_tensor_2=input_tensor_2,
+                tf_func=tf.math.mod,
+                np_func=np.mod,
+                graph_node_output_shape=graph_node_output_shape,
+                graph_node_output=graph_node_output,
+                tf_layers_dict=tf_layers_dict,
+                **kwargs,
             )
-        tf_partial_model_outputs = None
 
     # Generation of TF OP
-    ### Overall model
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.math.mod(
             x=input_tensor_1 \
@@ -194,44 +192,6 @@ def make_node(
                     else tf.convert_to_tensor(input_tensor_2),
             name=graph_node.name,
         )
-    ### Partial model
-    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
-        tf_partial_model_outputs = \
-            [
-                tf.math.mod(
-                    x=tf_partial_model_inputs[0] \
-                        if not isinstance(tf_partial_model_inputs[0], np.ndarray) \
-                            else tf.convert_to_tensor(tf_partial_model_inputs[0]),
-                    y=tf_partial_model_inputs[1] \
-                        if not isinstance(tf_partial_model_inputs[1], np.ndarray) \
-                            else tf.convert_to_tensor(tf_partial_model_inputs[1]),
-                )
-            ]
-        tf_partial_model = tf.keras.Model(
-            inputs=tf_partial_model_inputs,
-            outputs=tf_partial_model_outputs,
-        )
-        test_data1 = None
-        if isinstance(input_tensor_1, np.ndarray):
-            test_data1 = input_tensor_1
-        test_data2 = None
-        if isinstance(input_tensor_2, np.ndarray):
-            test_data2 = input_tensor_2
-        tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
-            model=tf_partial_model,
-            inputs=tf_partial_model_inputs,
-            verification_datas=[
-                test_data1,
-                test_data2,
-            ]
-        )
-        tf_layers_dict[graph_node_output.name]['verification_data'] = \
-            list(tf_partial_model_result_infos.values())[0]
-        del tf_partial_model
-        del tf_partial_model_inputs
-        del tf_partial_model_outputs
-        del test_data1
-        del test_data2
 
     # Post-process transpose
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
