@@ -14,7 +14,7 @@ from onnx2tf.utils.common_functions import (
 )
 from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
 import importlib
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 
 
 class While_Loop_CustomLayer(tf.keras.layers.Layer):
@@ -125,12 +125,12 @@ def make_node(
             try:
                 op = importlib.import_module(f'onnx2tf.ops.Input')
             except ModuleNotFoundError as ex:
-                print(
-                    f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+                error(
+                    f'{optype} OP is not yet implemented.'
                 )
                 sys.exit(1)
             # substitution because saved_model does not allow colons
-            body_input.name = body_input.name.replace(':','_')
+            body_input.name = body_input.name.replace(':','__')
             # Substitution because saved_model does not allow leading slashes in op names
             if kwargs['output_signaturedefs']:
                 body_input.name = re.sub('^/', 'wa/', body_input.name)
@@ -147,12 +147,12 @@ def make_node(
             try:
                 op = importlib.import_module(f'onnx2tf.ops.{optype}')
             except ModuleNotFoundError as ex:
-                print(
-                    f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+                error(
+                    f'{optype} OP is not yet implemented.'
                 )
                 sys.exit(1)
             # substitution because saved_model does not allow colons
-            body_node.name = body_node.name.replace(':','_')
+            body_node.name = body_node.name.replace(':','__')
             # Substitution because saved_model does not allow leading slashes in op names
             if kwargs['output_signaturedefs']:
                 body_node.name = re.sub('^/', 'wa/', body_node.name)
@@ -249,8 +249,7 @@ def make_node(
         )
     # M is None and cond is None
     else:
-        print(
-            f'{Color.RED}ERROR:{Color.RESET} '+
+        error(
             f'Both M and cond in Loop are not set at the same time ' +
             f'Tensorflow.(PS. if you want to create a do-while loop ' +
             f'then please set cond to True or 1)\n' +
