@@ -14,7 +14,7 @@ from onnx2tf.utils.common_functions import (
 )
 from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
 import importlib
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 
 
 class While_Loop_CustomLayer(tf.keras.layers.Layer):
@@ -89,10 +89,10 @@ def make_node(
     ) if M is not None else tf.constant(tf.int32.max, tf.int32)
     M_name = None
     if not isinstance(graph_node_input_1, np.ndarray):
-        graph_node_input_1.name = graph_node_input_1.name.replace(':','_')
+        graph_node_input_1.name = graph_node_input_1.name.replace(':','__')
         M_name = graph_node_input_1.name
     else:
-        M_name = graph_node.inputs[0].name.replace(':','_')
+        M_name = graph_node.inputs[0].name.replace(':','__')
     M_name = f'{M_name}_M'
     if kwargs['output_signaturedefs']:
         M_name = re.sub('^/', 'wa/', M_name)
@@ -113,10 +113,10 @@ def make_node(
 
     cond_init_name = None
     if not isinstance(graph_node_input_2, np.ndarray):
-        graph_node_input_2.name = graph_node_input_2.name.replace(':','_')
+        graph_node_input_2.name = graph_node_input_2.name.replace(':','__')
         cond_init_name = graph_node_input_2.name
     else:
-        cond_init_name = graph_node.inputs[0].name.replace(':','_')
+        cond_init_name = graph_node.inputs[0].name.replace(':','__')
     cond_init_name = f'{cond_init_name}_cond_init'
     if kwargs['output_signaturedefs']:
         cond_init_name = re.sub('^/', 'wa/', cond_init_name)
@@ -177,12 +177,12 @@ def make_node(
     #         try:
     #             op = importlib.import_module(f'onnx2tf.ops.Input')
     #         except ModuleNotFoundError as ex:
-    #             print(
-    #                 f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+    #             error(
+    #                 f'{optype} OP is not yet implemented.'
     #             )
     #             sys.exit(1)
     #         # substitution because saved_model does not allow colons
-    #         body_input.name = body_input.name.replace(':','_')
+    #         body_input.name = body_input.name.replace(':','__')
     #         # Substitution because saved_model does not allow leading slashes in op names
     #         if kwargs['output_signaturedefs']:
     #             body_input.name = re.sub('^/', 'wa/', body_input.name)
@@ -199,12 +199,12 @@ def make_node(
     #         try:
     #             op = importlib.import_module(f'onnx2tf.ops.{optype}')
     #         except ModuleNotFoundError as ex:
-    #             print(
-    #                 f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+    #             error(
+    #                 f'{optype} OP is not yet implemented.'
     #             )
     #             sys.exit(1)
     #         # substitution because saved_model does not allow colons
-    #         body_node.name = body_node.name.replace(':','_')
+    #         body_node.name = body_node.name.replace(':','__')
     #         # Substitution because saved_model does not allow leading slashes in op names
     #         if kwargs['output_signaturedefs']:
     #             body_node.name = re.sub('^/', 'wa/', body_node.name)
@@ -238,12 +238,12 @@ def make_node(
             try:
                 op = importlib.import_module(f'onnx2tf.ops.Input')
             except ModuleNotFoundError as ex:
-                print(
-                    f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+                error(
+                    f'{optype} OP is not yet implemented.'
                 )
                 sys.exit(1)
             # substitution because saved_model does not allow colons
-            body_input.name = body_input.name.replace(':','_')
+            body_input.name = body_input.name.replace(':','__')
             # Substitution because saved_model does not allow leading slashes in op names
             if kwargs['output_signaturedefs']:
                 body_input.name = re.sub('^/', 'wa/', body_input.name)
@@ -260,12 +260,12 @@ def make_node(
             try:
                 op = importlib.import_module(f'onnx2tf.ops.{optype}')
             except ModuleNotFoundError as ex:
-                print(
-                    f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+                error(
+                    f'{optype} OP is not yet implemented.'
                 )
                 sys.exit(1)
             # substitution because saved_model does not allow colons
-            body_node.name = body_node.name.replace(':','_')
+            body_node.name = body_node.name.replace(':','__')
             # Substitution because saved_model does not allow leading slashes in op names
             if kwargs['output_signaturedefs']:
                 body_node.name = re.sub('^/', 'wa/', body_node.name)
@@ -304,12 +304,12 @@ def make_node(
         try:
             op = importlib.import_module(f'onnx2tf.ops.Input')
         except ModuleNotFoundError as ex:
-            print(
-                f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+            error(
+                f'{optype} OP is not yet implemented.'
             )
             sys.exit(1)
         # substitution because saved_model does not allow colons
-        body_input.name = body_input.name.replace(':','_')
+        body_input.name = body_input.name.replace(':','__')
         # Substitution because saved_model does not allow leading slashes in op names
         if kwargs['output_signaturedefs']:
             body_input.name = re.sub('^/', 'wa/', body_input.name)
@@ -327,12 +327,12 @@ def make_node(
         try:
             op = importlib.import_module(f'onnx2tf.ops.{optype}')
         except ModuleNotFoundError as ex:
-            print(
-                f'{Color.RED}ERROR:{Color.RESET} {optype} OP is not yet implemented.'
+            error(
+                f'{optype} OP is not yet implemented.'
             )
             sys.exit(1)
         # substitution because saved_model does not allow colons
-        body_node.name = body_node.name.replace(':','_')
+        body_node.name = body_node.name.replace(':','__')
         # Substitution because saved_model does not allow leading slashes in op names
         if kwargs['output_signaturedefs']:
             body_node.name = re.sub('^/', 'wa/', body_node.name)
@@ -452,8 +452,7 @@ def make_node(
 
     # M is None and cond is None
     else:
-        print(
-            f'{Color.RED}ERROR:{Color.RESET} '+
+        error(
             f'Both M and cond in Loop are not set at the same time ' +
             f'Tensorflow.(PS. if you want to create a do-while loop ' +
             f'then please set cond to True or 1)\n' +
